<xsl:stylesheet  
  xmlns:xsl='http://www.w3.org/1999/XSL/Transform' 
  xmlns:saxon="http://icl.com/saxon" 
  xmlns:html="http://www.w3.org/TR/REC-html40"
  extension-element-prefixes="saxon" version="1.0">

<xsl:import href="../../../share/XSLT/descriptionTop.xslt"/>

<xsl:output method="html"/>

<xsl:param name="pwd"/>
<xsl:param name="basePath"/>

<xsl:variable name="zvonItemid" select="document('../Data/frontpage.xml')/frontPage/@idref"/>

<xsl:variable name="cells" select="8"/>

<xsl:template name="header">
  <xsl:param name="name"/>
  <table width="100%" cellpadding="2">
    <tr>
      <td>
	<xsl:apply-templates select="/chars/ascii[substring(@name,1,1)='_']" mode="index">
	  <xsl:with-param name="name" select="$name"/>
	</xsl:apply-templates>
      </td>
    </tr>
    <tr>
      <td>
	<xsl:apply-templates select="/chars/ascii[@lower][not(substring(@name,1,1)='_')]" mode="index">
	  <xsl:with-param name="name" select="$name"/>
	</xsl:apply-templates>
      </td>
    </tr>
  </table>
</xsl:template>

<xsl:key name="lower" match="ascii" use="@name"/>

<xsl:template match="chars">
  <xsl:apply-templates select="ascii[@lower]"/>
</xsl:template>


<xsl:template match="ascii" mode="index">
  <xsl:param name="name"/>
  <xsl:text> &#160; </xsl:text>
  <xsl:choose>
    <xsl:when test="$name = @name">
      <b>&gt;&gt; <xsl:value-of select="translate(@name,'_','')"/> &lt;&lt;</b>
    </xsl:when>
    <xsl:otherwise>
      <a href="{@name}.html" class="menu">&#160;<xsl:value-of select="translate(@name,'_','')"/>&#160;</a>
    </xsl:otherwise>
  </xsl:choose>
</xsl:template>

<xsl:template match="ascii">
  <xsl:document href="{$pwd}Output/{@name}.html">
    <html>
      <head>
	<title>Zvon Characters</title>
	<link rel="stylesheet" type="text/css" href="../CSS/style.css"/>
      </head>
      <body>

	<xsl:call-template name="share_descriptionTop">
	  <xsl:with-param name="id" select="$zvonItemid"/>
	</xsl:call-template>

	<!-- xsl:copy-of select="$header"/ -->
	  <xsl:call-template name="header">
	    <xsl:with-param name="name" select="@name"/>
	  </xsl:call-template>
	<br/>
	<table class="chars" border="1" cellspacing="5" cellpadding="4">
	  <tr>
	    <th><xsl:value-of select="translate(@name,'_','')"/></th>
	  </tr>
	  <xsl:apply-templates select="char[position() mod $cells = 1]"/>
	  <xsl:apply-templates select="key('lower',@lower)" mode="lower"/>
	</table>
	<br/>

	<!-- table width="100%" cellspacing="0">
	  <tr>
	    <td  class='menu'>
	      &#160;&#160;<a class='menu' href="http://www.zvon.org">&#160;Zvon&#160;</a>
	    </td>
	    <td style="text-align:right"  class='menu'>
	      <a  class='menu' href="mailto:nicmila@systinet.com">&#160;Miloslav Nic&#160;</a>&#160;&#160;
	    </td>
	  </tr>
	</table -->

      </body>
    </html>
  </xsl:document>
</xsl:template>

<xsl:template match="ascii" mode="lower">
  <xsl:if test="not(substring(@name,1,1)='_')">
    <xsl:apply-templates select="char[position() mod $cells = 1]"/>
  </xsl:if>
</xsl:template>

<xsl:template name="chardata">
  <b><xsl:value-of select="@decimal"/></b><br/><br/>
  <a href="http://charts.unicode.org/Web/{@unicodeWeb}.html" class="glyph">&#160;<xsl:value-of select="."/>&#160;</a><br/><br/>
  <b><xsl:value-of select="@hexadecimal"/></b>
</xsl:template>

<xsl:template match="char">
  
  <tr>
    <td>
      <xsl:call-template name="chardata"/>
    </td>
    <xsl:apply-templates select="following-sibling::char[position() &lt; $cells]" mode="td"/>
  </tr>
</xsl:template>

<xsl:template match="char" mode="td">
    <td>
      <xsl:call-template name="chardata"/>
    </td>
</xsl:template>


</xsl:stylesheet>








