<xsl:stylesheet xmlns:xsl='http://www.w3.org/1999/XSL/Transform' xmlns:saxon="http://icl.com/saxon" extension-element-prefixes="saxon" version="1.1"> 

<xsl:import href="headers.xslt"/>

<xsl:param name="pwd"/>
<xsl:param name="basePath"/>


<xsl:variable name="css">../CSS/style.css</xsl:variable>

<xsl:output method="html"/>

<xsl:template match="/">
  <html>
    <head>
      <link rel="stylesheet" type="text/css" href="{$css}"/> 
      <title>XSLT 1.0: functions</title>
    </head>
    <body>
      <xsl:call-template name="index-header">
	<xsl:with-param name="on">operators</xsl:with-param>
	<xsl:with-param name="id" select="$zvonItemid"/>
      </xsl:call-template>

      <xsl:apply-templates select="//operator | //construct | document('../Data/axes.xml')//axis[@shortForm]">
	<xsl:sort select="@markup|@shortForm"/>
        <xsl:sort select="@description"/>
      </xsl:apply-templates>
    </body>
  </html>
</xsl:template>


<xsl:template match="operator">
  <div>
    <a href="operator_{@name}.html" target="mainWindow"><xsl:value-of select="@markup"/></a>
    <xsl:if test="@descr">
      <xsl:text> (</xsl:text><xsl:value-of select="@descr"/><xsl:text>)</xsl:text>
    </xsl:if>
  </div>

    <xsl:document href="{$pwd}../Output/operator_{@name}.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="{$css}"/>
	<title>XSLT 1.0: operator <xsl:value-of select="@name"/></title>
      </head>
      <body>
	<xsl:variable name="st">
	  <xsl:choose>
	    <xsl:when test="starts-with(name(/*),'xslt')">xslt</xsl:when>
	    <xsl:otherwise>xpath</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<xsl:variable name="label">
	  <xsl:choose>
	    <xsl:when test="starts-with(name(/*),'xslt')">XSLT</xsl:when>
	    <xsl:otherwise>XPath</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<xsl:call-template name="share_descriptionTop">
	  <xsl:with-param name="id" select="$zvonItemid"/>
	</xsl:call-template>

	<xsl:call-template name="description-header">
	  <xsl:with-param name="standard">
	    <xsl:value-of select="concat($st,'.html#',@standardAnchor)"/>
	  </xsl:with-param>
	</xsl:call-template>
	<h3>
	  <xsl:text></xsl:text>
	  <xsl:value-of select="$label"/>
	  <xsl:text> operator: </xsl:text>
	  <span class="return"><xsl:value-of select="@return"/></span>
 <xsl:text> </xsl:text>
	  <span class="type"><xsl:value-of select="pre/@type"/></span>
 <xsl:text> </xsl:text>
	  <span class="name"><xsl:value-of select="@markup"/></span>
 <xsl:text> </xsl:text>
	  <span class="type"><xsl:value-of select="post/@type"/></span>
	</h3>
	<xsl:value-of select="@descr"/>
	  <h3>Standard excerpt:</h3>
	  <xsl:for-each select="standard">
	  <p>
	  <xsl:value-of select="text()"/>
	  </p>
	  </xsl:for-each>
	  <xsl:if test="@level">
	  <h3>Precedence:</h3>
	  <xsl:variable name="level" select="@level"/>
	  <xsl:variable name="name" select="@name"/>
	  Operators with greater precedence:
	     <xsl:for-each select="../operator[@level &gt; $level]">
		<a><xsl:attribute name="href"><xsl:value-of select="concat('operator_', @name, '.html')"/></xsl:attribute><xsl:value-of select="@markup"/></a>
		<xsl:if test="@descr"><xsl:text>(</xsl:text><xsl:value-of select="@descr"/><xsl:text>)</xsl:text></xsl:if>
		<xsl:text> </xsl:text>
	     </xsl:for-each>
	  <br/>
	  Operators with equal precedence:
	     <xsl:for-each select="../operator[@level = $level][@name != $name]">
		<a><xsl:attribute name="href"><xsl:value-of select="concat('operator_', @name, '.html')"/></xsl:attribute><xsl:value-of select="@markup"/></a>
		<xsl:if test="@descr"><xsl:text>(</xsl:text><xsl:value-of select="@descr"/><xsl:text>)</xsl:text></xsl:if>
		<xsl:text> </xsl:text>
	     </xsl:for-each>
	  <br/>
	  Operators with less precedence:
	     <xsl:for-each select="../operator[@level &lt; $level]">
		<a><xsl:attribute name="href"><xsl:value-of select="concat('operator_', @name, '.html')"/></xsl:attribute><xsl:value-of select="@markup"/></a>
		<xsl:if test="@descr"><xsl:text>(</xsl:text><xsl:value-of select="@descr"/><xsl:text>)</xsl:text></xsl:if>
		<xsl:text> </xsl:text>
	     </xsl:for-each>
	  <br/>
	  </xsl:if>
	  <hr/>
<!--	  <b>Examples (xslt:xml): </b> 
	  <a href='../OutputOverview/operator_{@name}_frame.html'>Overview</a><br/>
	  <xsl:comment>AllStart</xsl:comment>
	  <xsl:comment>AllEnd</xsl:comment> -->
	  <p><b>Interactive xlab: </b>
	    <xsl:apply-templates select="document('../Data/xlab.xml')/xlab/xl/function[normalize-space(.)=current()/@name]"/>
	    <xsl:apply-templates select="document('../Data/xlab.xml')/xlab/xl/functions"/>
	</p>
	</body>
    </html>
  </xsl:document>
</xsl:template>

<xsl:template match="xl/function | xl/functions">
  <a href="{../@url}" target='_blank'> [<xsl:value-of select="../@name"/>] </a>
</xsl:template>

<xsl:template match="argument">
  <span class="argument"><xsl:value-of select="@type"/>
  <xsl:if test="@occur='zero-multiple'">*</xsl:if>
  <xsl:if test="@occur='zero-once'">?</xsl:if>

</span>
  <xsl:if test="not(position()=last())">
    <xsl:text>, </xsl:text>
  </xsl:if>
</xsl:template>

<xsl:template match="axis">
  <div>
    <a href="axis_{@name}.html" target="mainWindow"><xsl:value-of select="@shortForm"/></a>
    <xsl:if test="@name">
      <xsl:text> (</xsl:text><span class="axis"><xsl:value-of select="@name"/></span><xsl:text> axis short form)</xsl:text>
    </xsl:if>
  </div>
</xsl:template>

<xsl:template match="construct">
  <div>
    <a href="construct_{@name}.html" target="mainWindow">
    <xsl:if test="@nonliteral">
      <xsl:attribute name="class">nonliteral</xsl:attribute>
    </xsl:if>
    <xsl:value-of select="@markup"/>
    </a>
    <xsl:if test="@name">
      <xsl:text> (</xsl:text><span class="construct"><xsl:value-of select="@descr"/></span><xsl:text>)</xsl:text>
    </xsl:if>
  </div>
    <xsl:document href="{$pwd}../Output/construct_{@name}.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="{$css}"/>
	<title>XSLT 1.0: construct <xsl:value-of select="@name"/></title>
      </head>
      <body>
	<xsl:variable name="st">
	  <xsl:choose>
	    <xsl:when test="starts-with(name(/*),'xslt')">xslt</xsl:when>
	    <xsl:otherwise>xpath</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<xsl:variable name="label">
	  <xsl:choose>
	    <xsl:when test="starts-with(name(/*),'xslt')">XSLT</xsl:when>
	    <xsl:otherwise>XPath</xsl:otherwise>
	  </xsl:choose>
	</xsl:variable>

	<!-- xsl:call-template name="share_descriptionTop">
	  <xsl:with-param name="id" select="$zvonItemid"/>
	</xsl:call-template -->

	<xsl:call-template name="description-header">
	  <xsl:with-param name="standard">
	    <xsl:value-of select="concat($st,'.html#',@standardAnchor)"/>
	  </xsl:with-param>
	</xsl:call-template>
	<h3>
	  <xsl:text></xsl:text>
	  <xsl:value-of select="$label"/>
	  <xsl:text> construct: </xsl:text>
	  <xsl:copy-of select="syntax"/>
	</h3>
	  <h3>Standard excerpt:</h3>
	  <xsl:for-each select="standard">
	  <p>
	  <xsl:value-of select="text()"/>
	  </p>
	  </xsl:for-each>
	  <hr/>
	  <b>Examples (xslt:xml): </b> 
	  <a href='../OutputOverview/construct_{@name}_frame.html'>Overview</a><br/>
	  <xsl:comment>AllStart</xsl:comment>
	  <xsl:comment>AllEnd</xsl:comment>
	  <p><b>Interactive xlab: </b>
	    <xsl:apply-templates select="document('../Data/xlab.xml')/xlab/xl/function[normalize-space(.)=current()/@name]"/>
	    <xsl:apply-templates select="document('../Data/xlab.xml')/xlab/xl/functions"/>
	</p>
	</body>
    </html>
  </xsl:document>
</xsl:template>

</xsl:stylesheet>



